package org.jfedor.notificationremote;

import java.io.IOException;
import java.io.OutputStream;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.UUID;

import android.app.Notification;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.service.notification.NotificationListenerService;
import android.service.notification.StatusBarNotification;
import android.util.Log;

public class NotificationListener extends NotificationListenerService {
    
    private static final String TAG = "NotificationRemote";
    private static final String BLUETOOTH_ADDRESS = "xx:xx:xx:xx:xx:xx";

    @Override
    public void onNotificationPosted(StatusBarNotification sbn) {
        updateExternalNotification();
    }

    @Override
    public void onNotificationRemoved(StatusBarNotification sbn) {
        updateExternalNotification();
    }

    private void updateExternalNotification() {
        StatusBarNotification[] notifications = this.getActiveNotifications();
        boolean lightOn = false;
        for (int i=0; i<notifications.length; i++) {
            Notification n = notifications[i].getNotification(); 
            lightOn |= (n.defaults & Notification.DEFAULT_LIGHTS | n.flags & Notification.FLAG_SHOW_LIGHTS) != 0;
        }
        setExternalNotificationState(lightOn);
    }
    
    private void setExternalNotificationState(boolean state) {
        BluetoothSocket socket;
        OutputStream out;
        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
        BluetoothDevice device = adapter.getRemoteDevice(BLUETOOTH_ADDRESS);
        try {
            //socket = device.createRfcommSocketToServiceRecord(UUID.fromString("00001101-0000-1000-8000-00805F9B34FB"));
            Method m = device.getClass().getMethod("createRfcommSocket", new Class[] { int.class });
            socket = (BluetoothSocket) m.invoke(device, 1);
            socket.connect();
            out = socket.getOutputStream();
            out.write(state ? '1' : '0');
            socket.close();
            Thread.sleep(1000);
        } catch (IOException e) {
            e.printStackTrace();
        } catch (NoSuchMethodException e) {
            e.printStackTrace();
        } catch (IllegalArgumentException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InvocationTargetException e) {
            e.printStackTrace();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }
}
